"# digitalocean_access_spaces" 
アクセスするには以下のキー設定が必要です。
        SPACES_ACCESS_KEY  = os.getenv('SPACES_ACCESS_KEY')
        SPACES_SECRET_KEY  = os.getenv('SPACES_SECRET_KEY')
        SPACES_REGION      = os.getenv('SPACES_REGION')
        SPACES_BUCKET_NAME = os.getenv('SPACES_BUCKET_NAME')
